;********************************************************
;
;              Decorative light Controller
;                  ( 20 steps type )
;                                 Device : PIC16F628
;                                 Clock  : 4MHz
;                                 Author : Seiichi Inoue
;********************************************************

        list            p=pic16f628
        include         p16f628.inc
 __config _hs_osc & _wdt_off & _pwrte_on & _lvp_off & _boden_off
        errorlevel      -302    ;Eliminate bank warning

;**************  Operating condition  *******************

;*** Frequency of AC power. 50Hz or 60Hz
hz      equ    d'50'            ;Except 50Hz assume 60Hz

;*** Control Pattern.  Available 0 to 255 (unit=100ms)
;In Rising up and Falling down, when a value is smaller
;than 20, the value of 0,1,2,4,5 or 10 is recommended.
;And when a value is larger than 20, the value which can
;be divided among 20 is recommended. Such as 20,40,60...
;This recommendation is caused by the processing logic.
;The abnormal operation doesn't occur to the other value.
;The error of time arises somewhat.
;
; Pattern 0
p0_1    equ    d'10'            ;Start delay      (1sec)
p0_2    equ    d'5'             ;Rising up      (0.5sec)
p0_3    equ    d'5'             ;Bright         (0.5sec)
p0_4    equ    d'5'             ;Falling down   (0.5sec)
p0_5    equ    d'5'             ;Dim            (0.5sec)

; Pattern 1
p1_1    equ    d'0'             ;Start delay      (0sec)
p1_2    equ    d'10'            ;Rising up        (1sec)
p1_3    equ    d'10'            ;Bright           (1sec)
p1_4    equ    d'10'            ;Falling down     (1sec)
p1_5    equ    d'10'            ;Dim              (1sec)

; Pattern 2
p2_1    equ    d'20'            ;Start delay      (2sec)
p2_2    equ    d'10'            ;Rising up        (1sec)
p2_3    equ    d'10'            ;Bright           (1sec)
p2_4    equ    d'10'            ;Falling down     (1sec)
p2_5    equ    d'10'            ;Dim              (1sec)

; Pattern 3
p3_1    equ    d'0'             ;Start delay      (0sec)
p3_2    equ    d'20'            ;Rising up        (2sec)
p3_3    equ    d'20'            ;Bright           (2sec)
p3_4    equ    d'20'            ;Falling down     (2sec)
p3_5    equ    d'20'            ;Dim              (2sec)

; Pattern 4
p4_1    equ    d'40'            ;Start delay      (4sec)
p4_2    equ    d'20'            ;Rising up        (2sec)
p4_3    equ    d'20'            ;Bright           (2sec)
p4_4    equ    d'20'            ;Falling down     (2sec)
p4_5    equ    d'20'            ;Dim              (2sec)

; Pattern 5
p5_1    equ    d'0'             ;Start delay      (0sec)
p5_2    equ    d'40'            ;Rising up        (4sec)
p5_3    equ    d'20'            ;Bright           (2sec)
p5_4    equ    d'40'            ;Falling down     (4sec)
p5_5    equ    d'20'            ;Dim              (2sec)

; Pattern 6
p6_1    equ    d'60'            ;Start delay      (6sec)
p6_2    equ    d'40'            ;Rising up        (4sec)
p6_3    equ    d'20'            ;Bright           (2sec)
p6_4    equ    d'40'            ;Falling down     (4sec)
p6_5    equ    d'20'            ;Dim              (2sec)

; Pattern 7
p7_1    equ    d'0'             ;Start delay      (0sec)
p7_2    equ    d'0'             ;Rising up        (0sec)
p7_3    equ    d'10'            ;Bright           (1sec)
p7_4    equ    d'0'             ;Falling down     (0sec)
p7_5    equ    d'20'            ;Dim              (2sec)

; Pattern 8
p8_1    equ    d'10'            ;Start delay      (1sec)
p8_2    equ    d'0'             ;Rising up        (0sec)
p8_3    equ    d'10'            ;Bright           (1sec)
p8_4    equ    d'0'             ;Falling down     (0sec)
p8_5    equ    d'20'            ;Dim              (2sec)

; Pattern 9
p9_1    equ    d'0'             ;Start delay      (0sec)
p9_2    equ    d'240'           ;Rising up       (24sec)
p9_3    equ    d'0'             ;Bright           (0sec)
p9_4    equ    d'240'           ;Falling down    (24sec)
p9_5    equ    d'0'             ;Dim              (0sec)

;****************  Label Definition  ********************
        cblock  h'20'
tmr0_value                      ;Value set to TMR0
tmr0_index                      ;TMR0 index
porta_work                      ;PORTA work area
portb_work                      ;PORTB work area
triac1                          ;TRIAC1 data
triac2                          ;TRIAC2 data
triac3                          ;TRIAC3 data
triac4                          ;TRIAC4 data
triac5                          ;TRIAC5 data
sw1_mode                        ;BCD SW1 mode
sw2_mode                        ;BCD SW2 mode
sw3_mode                        ;BCD SW3 mode
sw4_mode                        ;BCD SW4 mode
sw5_mode                        ;BCD SW5 mode
sw_count                        ;BCD SW scan counter
p_count                         ;Pattern trigger counter
s_count                         ;Switch read wait counter

;TRIAC1 work area
t1_s                            ;Start delay
t1_r                            ;Rising up
t1_b                            ;Bright
t1_f                            ;Falling down
t1_d                            ;Dim
t1_proc                         ;Process No.
t1_count                        ;Counter
t1_flag                         ;Counter Flag
t1_index                        ;Index
t1_subindex                     ;Sub Index

;TRIAC2 work area
t2_s                            ;Start delay
t2_r                            ;Rising up
t2_b                            ;Bright
t2_f                            ;Falling down
t2_d                            ;Dim
t2_proc                         ;Process No.
t2_count                        ;Counter
t2_flag                         ;Counter Flag
t2_index                        ;Index
t2_subindex                     ;Sub Index

;TRIAC3 work area
t3_s                            ;Start delay
t3_r                            ;Rising up
t3_b                            ;Bright
t3_f                            ;Falling down
t3_d                            ;Dim
t3_proc                         ;Process No.
t3_count                        ;Counter
t3_flag                         ;Counter Flag
t3_index                        ;Index
t3_subindex                     ;Sub Index

;TRIAC4 work area
t4_s                            ;Start delay
t4_r                            ;Rising up
t4_b                            ;Bright
t4_f                            ;Falling down
t4_d                            ;Dim
t4_proc                         ;Process No.
t4_count                        ;Counter
t4_flag                         ;Counter Flag
t4_index                        ;Index
t4_subindex                     ;Sub Index

;TRIAC5 work area
t5_s                            ;Start delay
t5_r                            ;Rising up
t5_b                            ;Bright
t5_f                            ;Falling down
t5_d                            ;Dim
t5_proc                         ;Process No.
t5_count                        ;Counter
t5_flag                         ;Counter Flag
t5_index                        ;Index
t5_subindex                     ;Sub Index
        endc

ra0     equ     00              ;RA0 bit
ra1     equ     01              ;RA1 bit
ra2     equ     02              ;RA2 bit
ra3     equ     03              ;RA3 bit
ra4     equ     04              ;RA4 bit


;***************** Program Start ************************
        org     0               ;Reset Vector
        goto    init
        org     4               ;Interrupt Vector
        goto    int

;******************* Initial Process ********************
init
;*** Set Port mode
        bsf     status,rp0      ;Change to Bank1
        movlw   b'00000000'     ;RA4-0:OUT mode
        movwf   trisa           ;Set TRISA reg
        movlw   b'00011111'     ;RB4-0:IN RB7-5:OUT mode
        movwf   trisb           ;Set TRISB reg

;*** Set Option reg
        movlw   b'01000000'     ;RBPU=ON,INTEDG=ON,PS=1:2
        movwf   option_reg      ;Set OPTION_REG

;*** Set PIE1 reg
        movlw   b'00000001'     ;TMR1IE=ON
        movwf   pie1            ;Set PIE1 reg
        bcf     status,rp0      ;Change to Bank0

;*** Set CMCON reg
        movlw   b'00000111'     ;RA port to digital
        movwf   cmcon           ;Set CMCON reg

;*** Set T1CON reg
        movlw   b'00000001'     ;T1CKPS=1:1,TMR1=ON
        movwf   t1con           ;Set T1CON reg

;*** Set TMR0 reg
        movlw   d'50'           ;Set check data
        sublw   hz              ;Check frequency
        btfss   status,z        ;50Hz ?
        goto    hz60            ;No.
        movlw   d'9'            ;256-500us/2us=6+Adj
        goto    tmr0set
hz60
        movlw   d'51'           ;256-417us/2us=48+Adj
tmr0set
        movwf   tmr0_value      ;Save TMR0 value
        movwf   tmr0            ;Set TMR0

;*** Set TMR1H,TMR1L reg (50ms)
        movlw   h'3c'           ;65536-50000us=15536+Adj
        movwf   tmr1h           ;d'15550' = h'3CBE'
        movlw   h'be'           ;Set TMR1H = h'3C'
        movwf   tmr1l           ;Set TMR1L = h'BE'

;*** Other registers and work area initialization
        clrf    porta           ;Clear PORTA
        clrf    portb           ;Clear PORTB
        clrf    tmr0_index      ;Clear TMR0 index
        clrf    porta_work      ;Clear PORTA work area
        movlw   d'20'           ;Set TRIAC OFF data
        movwf   triac1          ;Set TRIAC1 data
        movwf   triac2          ;Set TRIAC2 data
        movwf   triac3          ;Set TRIAC3 data
        movwf   triac4          ;Set TRIAC4 data
        movwf   triac5          ;Set TRIAC5 data
        movlw   d'2'            ;Set value
        movwf   p_count         ;Set pattten trigger cnt
        clrf    sw_count        ;Clear switch scan count
        clrf    sw1_mode        ;Clear switch mode TRIAC1
        clrf    sw2_mode        ;Clear switch mode TRIAC2
        clrf    sw3_mode        ;Clear switch mode TRIAC3
        clrf    sw4_mode        ;Clear switch mode TRIAC4
        clrf    sw5_mode        ;Clear switch mode TRIAC5
        clrf    t1_proc         ;Clear process for TRIAC1
        clrf    t2_proc         ;Clear process for TRIAC2
        clrf    t3_proc         ;Clear process for TRIAC3
        clrf    t4_proc         ;Clear process for TRIAC4
        clrf    t5_proc         ;Clear process for TRIAC5

;*** Set interrupt condition
        movlw   b'11110000'     ;GIE,PEIE,TOIE,INTE=1
        movwf   intcon          ;Interruption enable

        goto    $               ;Wait interruption

int
;*********** Interruption process beginning *************
        btfsc   intcon,intf     ;RB0 interruption ?
        goto    rb0_int         ;Jump to RB0 interruption
        btfsc   intcon,t0if     ;TMR0 time out ?
        goto    tmr0_int        ;Jump to TMR0 time-out
        btfsc   pir1,tmr1if     ;TMR1 time out ?
        goto    tmr1_int        ;Jump to TMR1 time-out
        goto    init            ;Reset(Illegal interrupt)

int_end
;************* END of interruption process **************
        retfie

rb0_int
;*************** RB0 interruption process ***************
        bcf     intcon,intf     ;Clear RB0 int flag
        bcf     intcon,t0if     ;Clear TMR0 int flag
        movfw   tmr0_value      ;Set timer value
        movwf   tmr0            ;Set TMR0
        clrf    tmr0_index      ;Clear TMR0 index
        clrf    porta_work      ;Clear PORTA work area
        clrf    porta           ;Clear PORTA

        goto    int_end         ;End of RB0 interruption

tmr0_int
;************** TMR0 interruption process ***************
        bcf     intcon,t0if     ;Clear TMR0 int flag
        movfw   tmr0_value      ;Set timer value
        movwf   tmr0            ;Set TMR0

        incf    tmr0_index,f    ;TMR0 index + 1
tmr0_triac1
        movfw   triac1          ;Read TRIAC1 data
        subwf   tmr0_index,w    ;Check TMR0 index
        btfss   status,c        ;TRIAC1 =< index ?
        goto    tmr0_triac2     ;No. Next
        bsf     porta_work,ra0  ;Set TRIAC1 ON
tmr0_triac2
        movfw   triac2          ;Read TRIAC2 data
        subwf   tmr0_index,w    ;Check TMR0 index
        btfss   status,c        ;TRIAC2 =< index ?
        goto    tmr0_triac3     ;No. Next
        bsf     porta_work,ra1  ;Set TRIAC2 ON
tmr0_triac3
        movfw   triac3          ;Read TRIAC3 data
        subwf   tmr0_index,w    ;Check TMR0 index
        btfss   status,c        ;TRIAC3 =< index ?
        goto    tmr0_triac4     ;No. Next
        bsf     porta_work,ra2  ;Set TRIAC3 ON
tmr0_triac4
        movfw   triac4          ;Read TRIAC4 data
        subwf   tmr0_index,w    ;Check TMR0 index
        btfss   status,c        ;TRIAC4 =< index ?
        goto    tmr0_triac5     ;No. Next
        bsf     porta_work,ra3  ;Set TRIAC4 ON
tmr0_triac5
        movfw   triac5          ;Read TRIAC5 data
        subwf   tmr0_index,w    ;Check TMR0 index
        btfss   status,c        ;TRIAC5 =< index ?
        goto    tmr0_end        ;No. go to end
        bsf     porta_work,ra4  ;Set TRIAC5 ON
tmr0_end
        movfw   porta_work      ;Read PORTA work area
        movwf   porta           ;Write PORTA

        goto    int_end         ;End of TMR0 interruption

tmr1_int
;***** Timer1 interruption process (50ms interval) ******
        bcf     pir1,tmr1if     ;Clear TMR1 int flag
        movlw   h'3c'           ;Set TMR1H value
        movwf   tmr1h           ;Set TMR1H
        movlw   h'be'           ;Set TMR1L value
        movwf   tmr1l           ;Set TMR1L

;*** BCD switch scanning
sw1
        movfw   sw_count        ;Read switch scan position
        btfss   status,z        ;Switch 1 ?
        goto    sw2             ;No. Next
        movlw   b'00000000'     ;Set scan data
        call    sw_mode_sub     ;Call SW mode pick up
        movfw   portb_work      ;Read PORTB data
        subwf   sw1_mode,w      ;Check PORTB data
        btfsc   status,z        ;PORTB changed ?
        goto    sw_end          ;No. Jump to sw scan end
        clrf    t1_proc         ;Set process to 0
        movfw   portb_work      ;Read PORTB data
        movwf   sw1_mode        ;Save SW1 mode
        goto    sw_end          ;Jump to sw scan end
sw2
        movlw   d'1'            ;Set check data
        subwf   sw_count,w      ;Check position data
        btfss   status,z        ;Switch 2 ?
        goto    sw3             ;No. Next
        movlw   b'00100000'     ;Set scan data
        call    sw_mode_sub     ;Call SW mode pick up
        movfw   portb_work      ;Read PORTB data
        subwf   sw2_mode,w      ;Check PORTB data
        btfsc   status,z        ;PORTB changed ?
        goto    sw_end          ;No. Jump to sw scan end
        clrf    t2_proc         ;Set process to 0
        movfw   portb_work      ;Read PORTB data
        movwf   sw2_mode        ;Save SW2 mode
        goto    sw_end          ;Jump to sw scan end
sw3
        movlw   d'2'            ;Set check data
        subwf   sw_count,w      ;Check position data
        btfss   status,z        ;Switch 3 ?
        goto    sw4             ;No. Next
        movlw   b'01000000'     ;Set scan data
        call    sw_mode_sub     ;Call SW mode pick up
        movfw   portb_work      ;Read PORTB data
        subwf   sw3_mode,w      ;Check PORTB data
        btfsc   status,z        ;PORTB changed ?
        goto    sw_end          ;No. Jump to sw scan end
        clrf    t3_proc         ;Set process to 0
        movfw   portb_work      ;Read PORTB data
        movwf   sw3_mode        ;Save SW3 mode
        goto    sw_end          ;Jump to sw scan end
sw4
        movlw   d'3'            ;Set check data
        subwf   sw_count,w      ;Check position data
        btfss   status,z        ;Switch 4 ?
        goto    sw5             ;No. Next
        movlw   b'01100000'     ;Set scan data
        call    sw_mode_sub     ;Call SW mode pick up
        movfw   portb_work      ;Read PORTB data
        subwf   sw4_mode,w      ;Check PORTB data
        btfsc   status,z        ;PORTB changed ?
        goto    sw_end          ;No. Jump to sw scan end
        clrf    t4_proc         ;Set process to 0
        movfw   portb_work      ;Read PORTB data
        movwf   sw4_mode        ;Save SW4 mode
        goto    sw_end          ;Jump to sw scan end
sw5
        movlw   d'4'            ;Set check data
        subwf   sw_count,w      ;Check position data
        btfss   status,z        ;Switch 5 ?
        goto    sw_end          ;No. Jump to sw scan end
        movlw   b'10000000'     ;Set scan data
        call    sw_mode_sub     ;Call SW mode pick up
        movfw   portb_work      ;Read PORTB data
        subwf   sw5_mode,w      ;Check PORTB data
        btfsc   status,z        ;PORTB changed ?
        goto    sw_end          ;No. Jump to sw scan end
        clrf    t5_proc         ;Set process to 0
        movfw   portb_work      ;Read PORTB data
        movwf   sw5_mode        ;Save SW5 mode

sw_end
        incf    sw_count,f      ;Switch position + 1
        movfw   sw_count        ;Read switch counter
        sublw   d'4'            ;Set check data
        btfss   status,c        ;Count over ?
        clrf    sw_count        ;Clear switch counter
        goto    ptn_cnt         ;Jump to pattern check

sw_mode_sub
        movwf   portb           ;Write scan data
        movlw   d'2'            ;Set 7us wait
        movwf   s_count         ;Save count
loop
        decfsz  s_count,f       ;7us ?
        goto    loop            ;No.
        movfw   portb           ;Read PORTB
        movwf   portb_work      ;Save PORTB data
        rrf     portb_work,f    ;Rotate Right
        movlw   b'00001111'     ;Set mask
        xorwf   portb_work,f    ;Reverse over BCD data
        andwf   portb_work,f    ;Pick up BCD data
        return

;*** Check pattern process timing
ptn_cnt
        decfsz  p_count,f       ;100ms ?
        goto    int_end         ;No. Next timing
        movlw   d'2'            ;Set trigger count data
        movwf   p_count         ;Set pattten trigger

;*********** Pattern process (100ms interval) ***********

;******************* Initial process ********************
;*** Initial process for TRIAC1
pp010
        movfw   t1_proc         ;Read process for TRIAC1
        btfss   status,z        ;Initial process ?
        goto    pp020           ;No. Jump to TRIAC2
        movlw   d'20'           ;Set TRIAC OFF data
        movwf   triac1          ;TRIAC1 off
        movlw   d'0'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 0 ?
        goto    pp011           ;No. Next
pp010s
        movlw   p0_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p0_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p0_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p0_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p0_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp011
        movlw   d'1'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 1 ?
        goto    pp012           ;No. Next
        movlw   p1_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p1_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p1_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p1_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p1_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp012
        movlw   d'2'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 2 ?
        goto    pp013           ;No. Next
        movlw   p2_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p2_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p2_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p2_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p2_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp013
        movlw   d'3'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 3 ?
        goto    pp014           ;No. Next
        movlw   p3_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p3_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p3_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p3_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p3_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp014
        movlw   d'4'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 4 ?
        goto    pp015           ;No. Next
        movlw   p4_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p4_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p4_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p4_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p4_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp015
        movlw   d'5'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 5 ?
        goto    pp016           ;No. Next
        movlw   p5_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p5_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p5_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p5_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p5_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp016
        movlw   d'6'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 6 ?
        goto    pp017           ;No. Next
        movlw   p6_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p6_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p6_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p6_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p6_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp017
        movlw   d'7'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 7 ?
        goto    pp018           ;No. Next
        movlw   p7_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p7_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p7_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p7_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p7_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp018
        movlw   d'8'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 8 ?
        goto    pp019           ;No. Next
        movlw   p8_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p8_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p8_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p8_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p8_5            ;Set Dim
        movwf   t1_d            ;Save Dim
        goto    pp01e           ;Jump to end of process1
pp019
        movlw   d'9'            ;Set check data
        subwf   sw1_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 9 ?
        goto    pp010s          ;Assume pattern 0
        movlw   p9_1            ;Set Start delay
        movwf   t1_s            ;Save Start delay
        movlw   p9_2            ;Set Rising up
        movwf   t1_r            ;Save Rising up
        movlw   p9_3            ;Set Bright
        movwf   t1_b            ;Save Bright
        movlw   p9_4            ;Set Falling down
        movwf   t1_f            ;Save Falling down
        movlw   p9_5            ;Set Dim
        movwf   t1_d            ;Save Dim

;End of Initial process for TRIAC1
pp01e
        movfw   t1_s            ;Read Start delay
        movwf   t1_count        ;Set Start delay to count
        incf    t1_count,f      ;Count + 1
        incf    t1_proc,f       ;Set process to 1

;*** Initial process for TRIAC2
pp020
        movfw   t2_proc         ;Read process for TRIAC2
        btfss   status,z        ;Initial process ?
        goto    pp030           ;No. Jump to TRIAC 3
        movlw   d'20'           ;Set TRIAC OFF data
        movwf   triac2          ;TRIAC2 off
        movlw   d'0'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 0 ?
        goto    pp021           ;No. Next
pp020s
        movlw   p0_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p0_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p0_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p0_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p0_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp021
        movlw   d'1'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 1 ?
        goto    pp022           ;No. Next
        movlw   p1_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p1_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p1_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p1_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p1_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp022
        movlw   d'2'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 2 ?
        goto    pp023           ;No. Next
        movlw   p2_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p2_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p2_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p2_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p2_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp023
        movlw   d'3'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 3 ?
        goto    pp024           ;No. Next
        movlw   p3_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p3_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p3_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p3_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p3_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp024
        movlw   d'4'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 4 ?
        goto    pp025           ;No. Next
        movlw   p4_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p4_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p4_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p4_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p4_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp025
        movlw   d'5'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 5 ?
        goto    pp026           ;No. Next
        movlw   p5_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p5_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p5_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p5_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p5_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp026
        movlw   d'6'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 6 ?
        goto    pp027           ;No. Next
        movlw   p6_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p6_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p6_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p6_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p6_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp027
        movlw   d'7'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 7 ?
        goto    pp028           ;No. Next
        movlw   p7_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p7_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p7_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p7_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p7_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp028
        movlw   d'8'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 8 ?
        goto    pp029           ;No. Next
        movlw   p8_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p8_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p8_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p8_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p8_5            ;Set Dim
        movwf   t2_d            ;Save Dim
        goto    pp02e           ;Jump to end of process1
pp029
        movlw   d'9'            ;Set check data
        subwf   sw2_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 9 ?
        goto    pp020s          ;Assume pattern 0
        movlw   p9_1            ;Set Start delay
        movwf   t2_s            ;Save Start delay
        movlw   p9_2            ;Set Rising up
        movwf   t2_r            ;Save Rising up
        movlw   p9_3            ;Set Bright
        movwf   t2_b            ;Save Bright
        movlw   p9_4            ;Set Falling down
        movwf   t2_f            ;Save Falling down
        movlw   p9_5            ;Set Dim
        movwf   t2_d            ;Save Dim

;End of Initial process for TRIAC2
pp02e
        movfw   t2_s            ;Read Start delay
        movwf   t2_count        ;Set Start delay to count
        incf    t2_count,f      ;Count + 1
        incf    t2_proc,f       ;Set process to 1

;*** Initial process for TRIAC3
pp030
        movfw   t3_proc         ;Read process for TRIAC3
        btfss   status,z        ;Initial process ?
        goto    pp040           ;No. Jump to TRIAC 4
        movlw   d'20'           ;Set TRIAC OFF data
        movwf   triac3          ;TRIAC3 off
        movlw   d'0'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 0 ?
        goto    pp031           ;No. Next
pp030s
        movlw   p0_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p0_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p0_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p0_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p0_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp031
        movlw   d'1'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 1 ?
        goto    pp032           ;No. Next
        movlw   p1_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p1_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p1_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p1_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p1_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp032
        movlw   d'2'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 2 ?
        goto    pp033           ;No. Next
        movlw   p2_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p2_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p2_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p2_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p2_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp033
        movlw   d'3'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 3 ?
        goto    pp034           ;No. Next
        movlw   p3_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p3_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p3_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p3_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p3_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp034
        movlw   d'4'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 4 ?
        goto    pp035           ;No. Next
        movlw   p4_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p4_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p4_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p4_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p4_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp035
        movlw   d'5'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 5 ?
        goto    pp036           ;No. Next
        movlw   p5_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p5_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p5_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p5_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p5_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp036
        movlw   d'6'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 6 ?
        goto    pp037           ;No. Next
        movlw   p6_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p6_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p6_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p6_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p6_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp037
        movlw   d'7'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 7 ?
        goto    pp038           ;No. Next
        movlw   p7_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p7_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p7_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p7_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p7_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp038
        movlw   d'8'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 8 ?
        goto    pp039           ;No. Next
        movlw   p8_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p8_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p8_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p8_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p8_5            ;Set Dim
        movwf   t3_d            ;Save Dim
        goto    pp03e           ;Jump to end of process1
pp039
        movlw   d'9'            ;Set check data
        subwf   sw3_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 9 ?
        goto    pp030s          ;Assume pattern 0
        movlw   p9_1            ;Set Start delay
        movwf   t3_s            ;Save Start delay
        movlw   p9_2            ;Set Rising up
        movwf   t3_r            ;Save Rising up
        movlw   p9_3            ;Set Bright
        movwf   t3_b            ;Save Bright
        movlw   p9_4            ;Set Falling down
        movwf   t3_f            ;Save Falling down
        movlw   p9_5            ;Set Dim
        movwf   t3_d            ;Save Dim

;End of Initial process for TRIAC3
pp03e
        movfw   t3_s            ;Read Start delay
        movwf   t3_count        ;Set Start delay to count
        incf    t3_count,f      ;Count + 1
        incf    t3_proc,f       ;Set process to 1

;*** Initial process for TRIAC4
pp040
        movfw   t4_proc         ;Read process for TRIAC4
        btfss   status,z        ;Initial process ?
        goto    pp050           ;No. Jump to TRIAC 5
        movlw   d'20'           ;Set TRIAC OFF data
        movwf   triac4          ;TRIAC4 off
        movlw   d'0'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 0 ?
        goto    pp041           ;No. Next
pp040s
        movlw   p0_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p0_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p0_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p0_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p0_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp041
        movlw   d'1'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 1 ?
        goto    pp042           ;No. Next
        movlw   p1_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p1_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p1_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p1_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p1_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp042
        movlw   d'2'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 2 ?
        goto    pp043           ;No. Next
        movlw   p2_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p2_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p2_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p2_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p2_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp043
        movlw   d'3'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 3 ?
        goto    pp044           ;No. Next
        movlw   p3_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p3_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p3_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p3_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p3_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp044
        movlw   d'4'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 4 ?
        goto    pp045           ;No. Next
        movlw   p4_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p4_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p4_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p4_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p4_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp045
        movlw   d'5'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 5 ?
        goto    pp046           ;No. Next
        movlw   p5_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p5_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p5_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p5_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p5_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp046
        movlw   d'6'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 6 ?
        goto    pp047           ;No. Next
        movlw   p6_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p6_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p6_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p6_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p6_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp047
        movlw   d'7'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 7 ?
        goto    pp048           ;No. Next
        movlw   p7_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p7_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p7_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p7_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p7_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp048
        movlw   d'8'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 8 ?
        goto    pp049           ;No. Next
        movlw   p8_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p8_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p8_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p8_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p8_5            ;Set Dim
        movwf   t4_d            ;Save Dim
        goto    pp04e           ;Jump to end of process1
pp049
        movlw   d'9'            ;Set check data
        subwf   sw4_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 9 ?
        goto    pp040s          ;Assume pattern 0
        movlw   p9_1            ;Set Start delay
        movwf   t4_s            ;Save Start delay
        movlw   p9_2            ;Set Rising up
        movwf   t4_r            ;Save Rising up
        movlw   p9_3            ;Set Bright
        movwf   t4_b            ;Save Bright
        movlw   p9_4            ;Set Falling down
        movwf   t4_f            ;Save Falling down
        movlw   p9_5            ;Set Dim
        movwf   t4_d            ;Save Dim

;End of Initial process for TRIAC4
pp04e
        movfw   t4_s            ;Read Start delay
        movwf   t4_count        ;Set Start delay to count
        incf    t4_count,f      ;Count + 1
        incf    t4_proc,f       ;Set process to 1

;*** Initial process for TRIAC5
pp050
        movfw   t5_proc         ;Read process for TRIAC5
        btfss   status,z        ;Initial process ?
        goto    pp110           ;No. Jump to Next process
        movlw   d'20'           ;Set TRIAC OFF data
        movwf   triac5          ;TRIAC5 off
        movlw   d'0'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 0 ?
        goto    pp051           ;No. Next
pp050s
        movlw   p0_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p0_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p0_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p0_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p0_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp051
        movlw   d'1'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 1 ?
        goto    pp052           ;No. Next
        movlw   p1_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p1_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p1_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p1_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p1_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp052
        movlw   d'2'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 2 ?
        goto    pp053           ;No. Next
        movlw   p2_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p2_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p2_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p2_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p2_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp053
        movlw   d'3'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 3 ?
        goto    pp054           ;No. Next
        movlw   p3_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p3_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p3_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p3_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p3_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp054
        movlw   d'4'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 4 ?
        goto    pp055           ;No. Next
        movlw   p4_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p4_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p4_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p4_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p4_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp055
        movlw   d'5'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 5 ?
        goto    pp056           ;No. Next
        movlw   p5_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p5_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p5_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p5_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p5_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp056
        movlw   d'6'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 6 ?
        goto    pp057           ;No. Next
        movlw   p6_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p6_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p6_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p6_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p6_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp057
        movlw   d'7'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 7 ?
        goto    pp058           ;No. Next
        movlw   p7_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p7_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p7_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p7_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p7_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp058
        movlw   d'8'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 8 ?
        goto    pp059           ;No. Next
        movlw   p8_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p8_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p8_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p8_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p8_5            ;Set Dim
        movwf   t5_d            ;Save Dim
        goto    pp05e           ;Jump to end of process1
pp059
        movlw   d'9'            ;Set check data
        subwf   sw5_mode,w      ;Check pattern
        btfss   status,z        ;Pattern = 9 ?
        goto    pp050s          ;Assume pattern 0
        movlw   p9_1            ;Set Start delay
        movwf   t5_s            ;Save Start delay
        movlw   p9_2            ;Set Rising up
        movwf   t5_r            ;Save Rising up
        movlw   p9_3            ;Set Bright
        movwf   t5_b            ;Save Bright
        movlw   p9_4            ;Set Falling down
        movwf   t5_f            ;Save Falling down
        movlw   p9_5            ;Set Dim
        movwf   t5_d            ;Save Dim

;End of Initial process for TRIAC5
pp05e
        movfw   t5_s            ;Read Start delay
        movwf   t5_count        ;Set Start delay to count
        incf    t5_count,f      ;Count + 1
        incf    t5_proc,f       ;Set process to 1

;***************** Start delay process ******************
;*** Start delay process for TRIAC1
pp110
        movlw   d'1'            ;Set check data
        subwf   t1_proc,w       ;Check data
        btfss   status,z        ;Start delay process ?
        goto    pp120           ;No. Jump to TRIAC2
        decfsz  t1_count,f      ;Count out ?
        goto    pp120           ;No. Jump to TRIAC2

;End of Start delay process for TRIAC1
        clrf    t1_index        ;Clear Index
        movfw   t1_r            ;Read Rising up data
        movwf   t1_count        ;Save Rising up data
        incf    t1_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t1_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp111           ;Data >= 20

; Data < 20
        clrf    t1_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t1_subindex     ;Save 20 as f
        movfw   t1_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp112           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp112           ;Jump to calculation

; Data >= 20
pp111
        movlw   d'1'            ;Set Flag data
        movwf   t1_flag         ;Set Flag = 1
        movfw   t1_r            ;Read Rising up data
        movwf   t1_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp112
        subwf   t1_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp113           ;Negative
        incf    t1_index,f      ;Positive, Index + 1
        goto    pp112           ;Again
pp113
        movfw   t1_index        ;Read index
        movwf   t1_subindex     ;Set subindex
        incf    t1_proc,f       ;Set process to 2

;*** Start delay process for TRIAC2
pp120
        movlw   d'1'            ;Set check data
        subwf   t2_proc,w       ;Check data
        btfss   status,z        ;Start delay process ?
        goto    pp130           ;No. Jump to TRIAC3
        decfsz  t2_count,f      ;Count out ?
        goto    pp130           ;No. Jump to TRIAC3

;End of Start delay process for TRIAC2
        clrf    t2_index        ;Clear Index
        movfw   t2_r            ;Read Rising up data
        movwf   t2_count        ;Save Rising up data
        incf    t2_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t2_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp121           ;Data >= 20

; Data < 20
        clrf    t2_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t2_subindex     ;Save 20 as f
        movfw   t2_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp122           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp122           ;Jump to calculation

; Data >= 20
pp121
        movlw   d'1'            ;Set Flag data
        movwf   t2_flag         ;Set Flag = 1
        movfw   t2_r            ;Read Rising up data
        movwf   t2_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp122
        subwf   t2_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp123           ;Negative
        incf    t2_index,f      ;Positive, Index + 1
        goto    pp122           ;Again
pp123
        movfw   t2_index        ;Read index
        movwf   t2_subindex     ;Set subindex
        incf    t2_proc,f       ;Set process to 2

;*** Start delay process for TRIAC3
pp130
        movlw   d'1'            ;Set check data
        subwf   t3_proc,w       ;Check data
        btfss   status,z        ;Start delay process ?
        goto    pp140           ;No. Jump to TRIAC4
        decfsz  t3_count,f      ;Count out ?
        goto    pp140           ;No. Jump to TRIAC4

;End of Start delay process for TRIAC3
        clrf    t3_index        ;Clear Index
        movfw   t3_r            ;Read Rising up data
        movwf   t3_count        ;Save Rising up data
        incf    t3_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t3_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp131           ;Data >= 20

; Data < 20
        clrf    t3_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t3_subindex     ;Save 20 as f
        movfw   t3_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp132           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp132           ;Jump to calculation

; Data >= 20
pp131
        movlw   d'1'            ;Set Flag data
        movwf   t3_flag         ;Set Flag = 1
        movfw   t3_r            ;Read Rising up data
        movwf   t3_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp132
        subwf   t3_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp133           ;Negative
        incf    t3_index,f      ;Positive, Index + 1
        goto    pp132           ;Again
pp133
        movfw   t3_index        ;Read index
        movwf   t3_subindex     ;Set subindex
        incf    t3_proc,f       ;Set process to 2

;*** Start delay process for TRIAC4
pp140
        movlw   d'1'            ;Set check data
        subwf   t4_proc,w       ;Check data
        btfss   status,z        ;Start delay process ?
        goto    pp150           ;No. Jump to TRIAC5
        decfsz  t4_count,f      ;Count out ?
        goto    pp150           ;No. Jump to TRIAC5

;End of Start delay process for TRIAC4
        clrf    t4_index        ;Clear Index
        movfw   t4_r            ;Read Rising up data
        movwf   t4_count        ;Save Rising up data
        incf    t4_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t4_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp141           ;Data >= 20

; Data < 20
        clrf    t4_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t4_subindex     ;Save 20 as f
        movfw   t4_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp142           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp142           ;Jump to calculation

; Data >= 20
pp141
        movlw   d'1'            ;Set Flag data
        movwf   t4_flag         ;Set Flag = 1
        movfw   t4_r            ;Read Rising up data
        movwf   t4_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp142
        subwf   t4_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp143           ;Negative
        incf    t4_index,f      ;Positive, Index + 1
        goto    pp142           ;Again
pp143
        movfw   t4_index        ;Read index
        movwf   t4_subindex     ;Set subindex
        incf    t4_proc,f       ;Set process to 2

;*** Start delay process for TRIAC5
pp150
        movlw   d'1'            ;Set check data
        subwf   t5_proc,w       ;Check data
        btfss   status,z        ;Start delay process ?
        goto    pp210           ;No. Jump to Next process
        decfsz  t5_count,f      ;Count out ?
        goto    pp210           ;No. Jump to Next process

;End of Start delay process for TRIAC5
        clrf    t5_index        ;Clear Index
        movfw   t5_r            ;Read Rising up data
        movwf   t5_count        ;Save Rising up data
        incf    t5_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t5_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp151           ;Data >= 20

; Data < 20
        clrf    t5_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t5_subindex     ;Save 20 as f
        movfw   t5_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp152           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp152           ;Jump to calculation

; Data >= 20
pp151
        movlw   d'1'            ;Set Flag data
        movwf   t5_flag         ;Set Flag = 1
        movfw   t5_r            ;Read Rising up data
        movwf   t5_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp152
        subwf   t5_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp153           ;Negative
        incf    t5_index,f      ;Positive, Index + 1
        goto    pp152           ;Again
pp153
        movfw   t5_index        ;Read index
        movwf   t5_subindex     ;Set subindex
        incf    t5_proc,f       ;Set process to 2

;****************** Rising up process *******************
;*** Rising up process for TRIAC1
pp210
        movlw   d'2'            ;Set check data
        subwf   t1_proc,w       ;Check data
        btfss   status,z        ;Rising up process ?
        goto    pp220           ;No. Jump to TRIAC2
        movfw   t1_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp213           ;No, Data >= 20

;Data < 20
        movfw   t1_subindex     ;Read subindex
        subwf   triac1,w        ;TRIAC1 data - Subindex
        btfsc   status,c        ;Result is negative ?
        goto    pp211           ;No. Decrease TRIAC1
        clrf    triac1          ;Clear TRIAC1 (Bright)
        goto    pp212
pp211
        movfw   t1_subindex     ;Read subindex
        subwf   triac1,f        ;TRIAC1 data - Subindex
pp212
        decfsz  t1_count,f      ;Count out ?
        goto    pp220           ;No. Jump to TRIAC2
        goto    pp21e           ;Jump to end of process2

;Data >= 20
pp213
        decfsz  t1_subindex,f   ;Subindex - 1
        goto    pp212           ;Jump to decrease count
        movlw   d'1'            ;Set data
        subwf   triac1,w        ;TRIAC1 data - 1
        btfsc   status,c        ;Result is negative ?
        goto    pp214           ;No. Decrease TRIAC1
        clrf    triac1          ;Clear TRIAC1 (Bright)
        goto    pp215           ;Jump to subindex setting
pp214
        decf    triac1,f        ;TRIAC1 - 1
pp215
        movfw   t1_index        ;Read index
        movwf   t1_subindex     ;Set subindex
        goto    pp212           ;Jump to decrease count

;End of Rising up process for TRIAC1
pp21e
        movfw   t1_b            ;Read Bright data
        movwf   t1_count        ;Save Bright data
        incf    t1_count,f      ;Count + 1
        incf    t1_proc,f       ;Set process to 3

;*** Rising up process for TRIAC2
pp220
        movlw   d'2'            ;Set check data
        subwf   t2_proc,w       ;Check data
        btfss   status,z        ;Rising up process ?
        goto    pp230           ;No. Jump to TRIAC3
        movfw   t2_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp223           ;No, Data >= 20

;Data < 20
        movfw   t2_subindex     ;Read subindex
        subwf   triac2,w        ;TRIAC2 data - Subindex
        btfsc   status,c        ;Result is negative ?
        goto    pp221           ;No. Decrease TRIAC2
        clrf    triac2          ;Clear TRIAC2 (Bright)
        goto    pp222
pp221
        movfw   t2_subindex     ;Read subindex
        subwf   triac2,f        ;TRIAC2 data - Subindex
pp222
        decfsz  t2_count,f      ;Count out ?
        goto    pp230           ;No. Jump to TRIAC3
        goto    pp22e           ;Jump to end of process2

;Data >= 20
pp223
        decfsz  t2_subindex,f   ;Subindex - 1
        goto    pp222           ;Jump to decrease count
        movlw   d'1'            ;Set data
        subwf   triac2,w        ;TRIAC2 data - 1
        btfsc   status,c        ;Result is negative ?
        goto    pp224           ;No. Decrease TRIAC2
        clrf    triac2          ;Clear TRIAC2 (Bright)
        goto    pp225           ;Jump to subindex setting
pp224
        decf    triac2,f        ;TRIAC2 - 1
pp225
        movfw   t2_index        ;Read index
        movwf   t2_subindex     ;Set subindex
        goto    pp222           ;Jump to decrease count

;End of Rising up process for TRIAC2
pp22e
        movfw   t2_b            ;Read Bright data
        movwf   t2_count        ;Save Bright data
        incf    t2_count,f      ;Count + 1
        incf    t2_proc,f       ;Set process to 3

;*** Rising up process for TRIAC3
pp230
        movlw   d'2'            ;Set check data
        subwf   t3_proc,w       ;Check data
        btfss   status,z        ;Rising up process ?
        goto    pp240           ;No. Jump to TRIAC4
        movfw   t3_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp233           ;No, Data >= 20

;Data < 20
        movfw   t3_subindex     ;Read subindex
        subwf   triac3,w        ;TRIAC3 data - Subindex
        btfsc   status,c        ;Result is negative ?
        goto    pp231           ;No. Decrease TRIAC3
        clrf    triac3          ;Clear TRIAC3 (Bright)
        goto    pp232
pp231
        movfw   t3_subindex     ;Read subindex
        subwf   triac3,f        ;TRIAC3 data - Subindex
pp232
        decfsz  t3_count,f      ;Count out ?
        goto    pp240           ;No. Jump to TRIAC4
        goto    pp23e           ;Jump to end of process2

;Data >= 20
pp233
        decfsz  t3_subindex,f   ;Subindex - 1
        goto    pp232           ;Jump to decrease count
        movlw   d'1'            ;Set data
        subwf   triac3,w        ;TRIAC3 data - 1
        btfsc   status,c        ;Result is negative ?
        goto    pp234           ;No. Decrease TRIAC3
        clrf    triac3          ;Clear TRIAC3 (Bright)
        goto    pp235           ;Jump to subindex setting
pp234
        decf    triac3,f        ;TRIAC3 - 1
pp235
        movfw   t3_index        ;Read index
        movwf   t3_subindex     ;Set subindex
        goto    pp232           ;Jump to decrease count

;End of Rising up process for TRIAC3
pp23e
        movfw   t3_b            ;Read Bright data
        movwf   t3_count        ;Save Bright data
        incf    t3_count,f      ;Count + 1
        incf    t3_proc,f       ;Set process to 3

;*** Rising up process for TRIAC4
pp240
        movlw   d'2'            ;Set check data
        subwf   t4_proc,w       ;Check data
        btfss   status,z        ;Rising up process ?
        goto    pp250           ;No. Jump to TRIAC5
        movfw   t4_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp243           ;No, Data >= 20

;Data < 20
        movfw   t4_subindex     ;Read subindex
        subwf   triac4,w        ;TRIAC4 data - Subindex
        btfsc   status,c        ;Result is negative ?
        goto    pp241           ;No. Decrease TRIAC4
        clrf    triac4          ;Clear TRIAC4 (Bright)
        goto    pp242
pp241
        movfw   t4_subindex     ;Read subindex
        subwf   triac4,f        ;TRIAC4 data - Subindex
pp242
        decfsz  t4_count,f      ;Count out ?
        goto    pp250           ;No. Jump to TRIAC5
        goto    pp24e           ;Jump to end of process2

;Data >= 20
pp243
        decfsz  t4_subindex,f   ;Subindex - 1
        goto    pp242           ;Jump to decrease count
        movlw   d'1'            ;Set data
        subwf   triac4,w        ;TRIAC4 data - 1
        btfsc   status,c        ;Result is negative ?
        goto    pp244           ;No. Decrease TRIAC4
        clrf    triac4          ;Clear TRIAC4 (Bright)
        goto    pp245           ;Jump to subindex setting
pp244
        decf    triac4,f        ;TRIAC4 - 1
pp245
        movfw   t4_index        ;Read index
        movwf   t4_subindex     ;Set subindex
        goto    pp242           ;Jump to decrease count

;End of Rising up process for TRIAC4
pp24e
        movfw   t4_b            ;Read Bright data
        movwf   t4_count        ;Save Bright data
        incf    t4_count,f      ;Count + 1
        incf    t4_proc,f       ;Set process to 3

;*** Rising up process for TRIAC5
pp250
        movlw   d'2'            ;Set check data
        subwf   t5_proc,w       ;Check data
        btfss   status,z        ;Rising up process ?
        goto    pp310           ;No. Jump to Next process
        movfw   t5_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp253           ;No, Data >= 20

;Data < 20
        movfw   t5_subindex     ;Read subindex
        subwf   triac5,w        ;TRIAC5 data - Subindex
        btfsc   status,c        ;Result is negative ?
        goto    pp251           ;No. Decrease TRIAC5
        clrf    triac5          ;Clear TRIAC5 (Bright)
        goto    pp252
pp251
        movfw   t5_subindex     ;Read subindex
        subwf   triac5,f        ;TRIAC5 data - Subindex
pp252
        decfsz  t5_count,f      ;Count out ?
        goto    pp310           ;No. Jump to Next process
        goto    pp25e           ;Jump to end of process2

;Data >= 20
pp253
        decfsz  t5_subindex,f   ;Subindex - 1
        goto    pp252           ;Jump to decrease count
        movlw   d'1'            ;Set data
        subwf   triac5,w        ;TRIAC5 data - 1
        btfsc   status,c        ;Result is negative ?
        goto    pp254           ;No. Decrease TRIAC5
        clrf    triac5          ;Clear TRIAC5 (Bright)
        goto    pp255           ;Jump to subindex setting
pp254
        decf    triac5,f        ;TRIAC5 - 1
pp255
        movfw   t5_index        ;Read index
        movwf   t5_subindex     ;Set subindex
        goto    pp252           ;Jump to decrease count

;End of Rising up process for TRIAC5
pp25e
        movfw   t5_b            ;Read Bright data
        movwf   t5_count        ;Save Bright data
        incf    t5_count,f      ;Count + 1
        incf    t5_proc,f       ;Set process to 3

;******************* Bright process *********************
;*** Bright process for TRIAC1
pp310
        movlw   d'3'            ;Set check data
        subwf   t1_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp320           ;No. Jump to TRIAC2
        decfsz  t1_count,f      ;Count out ?
        goto    pp320           ;No. Jump to TRIAC2

;End of Bright process for TRIAC1
        clrf    t1_index        ;Clear Index
        movfw   t1_f            ;Read Falling down data
        movwf   t1_count        ;Save Falling down data
        incf    t1_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t1_f,w          ;Check data
        btfsc   status,c        ;Falling down data < 20
        goto    pp311           ;Data >= 20

; Data < 20
        clrf    t1_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t1_subindex     ;Save 20 as f
        movfw   t1_f            ;Set Fall down data as w
        btfss   status,z        ;Falling down data = 0 ?
        goto    pp312           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp312           ;Jump to calculation

; Data >= 20
pp311
        movlw   d'1'            ;Set Flag data
        movwf   t1_flag         ;Set Flag = 1
        movfw   t1_f            ;Read Falling down data
        movwf   t1_subindex     ;Save Fall down data as f
        movlw   d'20'           ;Set 20 as w
pp312
        subwf   t1_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp313           ;Negative
        incf    t1_index,f      ;Positive, Index + 1
        goto    pp312           ;Again
pp313
        movfw   t1_index        ;Read index
        movwf   t1_subindex     ;Set subindex
        incf    t1_proc,f       ;Set process to 4

;*** Bright process for TRIAC2
pp320
        movlw   d'3'            ;Set check data
        subwf   t2_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp330           ;No. Jump to TRIAC3
        decfsz  t2_count,f      ;Count out ?
        goto    pp330           ;No. Jump to TRIAC3

;End of Bright process for TRIAC2
        clrf    t2_index        ;Clear Index
        movfw   t2_f            ;Read Falling down data
        movwf   t2_count        ;Save Falling down data
        incf    t2_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t2_f,w          ;Check data
        btfsc   status,c        ;Falling down data < 20
        goto    pp321           ;Data >= 20

; Data < 20
        clrf    t2_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t2_subindex     ;Save 20 as f
        movfw   t2_f            ;Set Fall down data as w
        btfss   status,z        ;Falling down data = 0 ?
        goto    pp322           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp322           ;Jump to calculation

; Data >= 20
pp321
        movlw   d'1'            ;Set Flag data
        movwf   t2_flag         ;Set Flag = 1
        movfw   t2_f            ;Read Falling down data
        movwf   t2_subindex     ;Save Fall down data as f
        movlw   d'20'           ;Set 20 as w
pp322
        subwf   t2_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp323           ;Negative
        incf    t2_index,f      ;Positive, Index + 1
        goto    pp322           ;Again
pp323
        movfw   t2_index        ;Read index
        movwf   t2_subindex     ;Set subindex
        incf    t2_proc,f       ;Set process to 4

;*** Bright process for TRIAC3
pp330
        movlw   d'3'            ;Set check data
        subwf   t3_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp340           ;No. Jump to TRIAC4
        decfsz  t3_count,f      ;Count out ?
        goto    pp340           ;No. Jump to TRIAC4

;End of Bright process for TRIAC3
        clrf    t3_index        ;Clear Index
        movfw   t3_f            ;Read Falling down data
        movwf   t3_count        ;Save Falling down data
        incf    t3_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t3_f,w          ;Check data
        btfsc   status,c        ;Falling down data < 20
        goto    pp331           ;Data >= 20

; Data < 20
        clrf    t3_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t3_subindex     ;Save 20 as f
        movfw   t3_f            ;Set Fall down data as w
        btfss   status,z        ;Falling down data = 0 ?
        goto    pp332           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp332           ;Jump to calculation

; Data >= 20
pp331
        movlw   d'1'            ;Set Flag data
        movwf   t3_flag         ;Set Flag = 1
        movfw   t3_f            ;Read Falling down data
        movwf   t3_subindex     ;Save Fall down data as f
        movlw   d'20'           ;Set 20 as w
pp332
        subwf   t3_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp333           ;Negative
        incf    t3_index,f      ;Positive, Index + 1
        goto    pp332           ;Again
pp333
        movfw   t3_index        ;Read index
        movwf   t3_subindex     ;Set subindex
        incf    t3_proc,f       ;Set process to 4

;*** Bright process for TRIAC4
pp340
        movlw   d'3'            ;Set check data
        subwf   t4_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp350           ;No. Jump to TRIAC5
        decfsz  t4_count,f      ;Count out ?
        goto    pp350           ;No. Jump to TRIAC5

;End of Bright process for TRIAC4
        clrf    t4_index        ;Clear Index
        movfw   t4_f            ;Read Falling down data
        movwf   t4_count        ;Save Falling down data
        incf    t4_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t4_f,w          ;Check data
        btfsc   status,c        ;Falling down data < 10
        goto    pp341           ;Data >= 20

; Data < 20
        clrf    t4_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t4_subindex     ;Save 20 as f
        movfw   t4_f            ;Set Fall down data as w
        btfss   status,z        ;Falling down data = 0 ?
        goto    pp342           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp342           ;Jump to calculation

; Data >= 20
pp341
        movlw   d'1'            ;Set Flag data
        movwf   t4_flag         ;Set Flag = 1
        movfw   t4_f            ;Read Falling down data
        movwf   t4_subindex     ;Save Fall down data as f
        movlw   d'20'           ;Set 20 as w
pp342
        subwf   t4_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp343           ;Negative
        incf    t4_index,f      ;Positive, Index + 1
        goto    pp342           ;Again
pp343
        movfw   t4_index        ;Read index
        movwf   t4_subindex     ;Set subindex
        incf    t4_proc,f       ;Set process to 4

;*** Bright process for TRIAC5
pp350
        movlw   d'3'            ;Set check data
        subwf   t5_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp410           ;No. Jump to Next process
        decfsz  t5_count,f      ;Count out ?
        goto    pp410           ;No. Jump to Next process

;End of Bright process for TRIAC4
        clrf    t5_index        ;Clear Index
        movfw   t5_f            ;Read Falling down data
        movwf   t5_count        ;Save Falling down data
        incf    t5_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t5_f,w          ;Check data
        btfsc   status,c        ;Falling down data < 20
        goto    pp351           ;Data >= 20

; Data < 20
        clrf    t5_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t5_subindex     ;Save 20 as f
        movfw   t5_f            ;Set Fall down data as w
        btfss   status,z        ;Falling down data = 0 ?
        goto    pp352           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp352           ;Jump to calculation

; Data >= 20
pp351
        movlw   d'1'            ;Set Flag data
        movwf   t5_flag         ;Set Flag = 1
        movfw   t5_f            ;Read Falling down data
        movwf   t5_subindex     ;Save Fall down data as f
        movlw   d'20'           ;Set 20 as w
pp352
        subwf   t5_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp353           ;Negative
        incf    t5_index,f      ;Positive, Index + 1
        goto    pp352           ;Again
pp353
        movfw   t5_index        ;Read index
        movwf   t5_subindex     ;Set subindex
        incf    t5_proc,f       ;Set process to 4

;**************** Falling down process ******************
;*** Falling down process for TRIAC1
pp410
        movlw   d'4'            ;Set check data
        subwf   t1_proc,w       ;Check data
        btfss   status,z        ;Falling down process ?
        goto    pp420           ;No. Jump to TRIAC2
        movfw   t1_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp412           ;No, Data >= 20

;Data < 20
        movfw   t1_subindex     ;Read subindex
        addwf   triac1,f        ;TRIAC1 data + Subindex
pp411
        decfsz  t1_count,f      ;Count out ?
        goto    pp420           ;No. Jump to TRIAC2
        goto    pp41e           ;Jump to end of process4

;Data >= 20
pp412
        decfsz  t1_subindex,f   ;Subindex - 1
        goto    pp411           ;Jump to decrease count
        incf    triac1,f        ;TRIAC1 data + 1
        movfw   t1_index        ;Read index
        movwf   t1_subindex     ;Set subindex
        goto    pp411           ;Jump to decrease count

;End of Falling down process for TRIAC1
pp41e
        movlw   d'20'           ;Set TRIAC1 dim data
        movwf   triac1          ;Write TRIAC1 data
        movfw   t1_d            ;Read Dim data
        movwf   t1_count        ;Save Dim data
        incf    t1_count,f      ;Count + 1
        incf    t1_proc,f       ;Set process to 5

;*** Falling down process for TRIAC2
pp420
        movlw   d'4'            ;Set check data
        subwf   t2_proc,w       ;Check data
        btfss   status,z        ;Falling down process ?
        goto    pp430           ;No. Jump to TRIAC3
        movfw   t2_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp422           ;No, Data >= 20

;Data < 20
        movfw   t2_subindex     ;Read subindex
        addwf   triac2,f        ;TRIAC2 data + Subindex
pp421
        decfsz  t2_count,f      ;Count out ?
        goto    pp430           ;No. Jump to TRIAC3
        goto    pp42e           ;Jump to end of process4

;Data >= 20
pp422
        decfsz  t2_subindex,f   ;Subindex - 1
        goto    pp421           ;Jump to decrease count
        incf    triac2,f        ;TRIAC2 data + 1
        movfw   t2_index        ;Read index
        movwf   t2_subindex     ;Set subindex
        goto    pp421           ;Jump to decrease count

;End of Falling down process for TRIAC2
pp42e
        movlw   d'20'           ;Set TRIAC2 dim data
        movwf   triac2          ;Write TRIAC2 data
        movfw   t2_d            ;Read Dim data
        movwf   t2_count        ;Save Dim data
        incf    t2_count,f      ;Count + 1
        incf    t2_proc,f       ;Set process to 5

;*** Falling down process for TRIAC3
pp430
        movlw   d'4'            ;Set check data
        subwf   t3_proc,w       ;Check data
        btfss   status,z        ;Falling down process ?
        goto    pp440           ;No. Jump to TRIAC4
        movfw   t3_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp432           ;No, Data >= 20

;Data < 20
        movfw   t3_subindex     ;Read subindex
        addwf   triac3,f        ;TRIAC3 data + Subindex
pp431
        decfsz  t3_count,f      ;Count out ?
        goto    pp440           ;No. Jump to TRIAC4
        goto    pp43e           ;Jump to end of process4

;Data >= 20
pp432
        decfsz  t3_subindex,f   ;Subindex - 1
        goto    pp431           ;Jump to decrease count
        incf    triac3,f        ;TRIAC3 data + 1
        movfw   t3_index        ;Read index
        movwf   t3_subindex     ;Set subindex
        goto    pp431           ;Jump to decrease count

;End of Falling down process for TRIAC3
pp43e
        movlw   d'20'           ;Set TRIAC3 dim data
        movwf   triac3          ;Write TRIAC3 data
        movfw   t3_d            ;Read Dim data
        movwf   t3_count        ;Save Dim data
        incf    t3_count,f      ;Count + 1
        incf    t3_proc,f       ;Set process to 5

;*** Falling down process for TRIAC4
pp440
        movlw   d'4'            ;Set check data
        subwf   t4_proc,w       ;Check data
        btfss   status,z        ;Falling down process ?
        goto    pp450           ;No. Jump to TRIAC5
        movfw   t4_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp442           ;No, Data >= 20

;Data < 20
        movfw   t4_subindex     ;Read subindex
        addwf   triac4,f        ;TRIAC4 data + Subindex
pp441
        decfsz  t4_count,f      ;Count out ?
        goto    pp450           ;No. Jump to TRIAC5
        goto    pp44e           ;Jump to end of process4

;Data >= 20
pp442
        decfsz  t4_subindex,f   ;Subindex - 1
        goto    pp441           ;Jump to decrease count
        incf    triac4,f        ;TRIAC4 data + 1
        movfw   t4_index        ;Read index
        movwf   t4_subindex     ;Set subindex
        goto    pp441           ;Jump to decrease count

;End of Falling down process for TRIAC4
pp44e
        movlw   d'20'           ;Set TRIAC4 dim data
        movwf   triac4          ;Write TRIAC4 data
        movfw   t4_d            ;Read Dim data
        movwf   t4_count        ;Save Dim data
        incf    t4_count,f      ;Count + 1
        incf    t4_proc,f       ;Set process to 5

;*** Falling down process for TRIAC5
pp450
        movlw   d'4'            ;Set check data
        subwf   t5_proc,w       ;Check data
        btfss   status,z        ;Falling down process ?
        goto    pp510           ;No. Jump to Next process
        movfw   t5_flag         ;Read Flag
        btfss   status,z        ;Data < 20 ?
        goto    pp452           ;No, Data >= 20

;Data < 20
        movfw   t5_subindex     ;Read subindex
        addwf   triac5,f        ;TRIAC5 data + Subindex
pp451
        decfsz  t5_count,f      ;Count out ?
        goto    pp510           ;No. Jump to Next process
        goto    pp45e           ;Jump to end of process4

;Data >= 20
pp452
        decfsz  t5_subindex,f   ;Subindex - 1
        goto    pp451           ;Jump to decrease count
        incf    triac5,f        ;TRIAC5 data + 1
        movfw   t5_index        ;Read index
        movwf   t5_subindex     ;Set subindex
        goto    pp451           ;Jump to decrease count

;End of Falling down process for TRIAC5
pp45e
        movlw   d'20'           ;Set TRIAC5 dim data
        movwf   triac5          ;Write TRIAC5 data
        movfw   t5_d            ;Read Dim data
        movwf   t5_count        ;Save Dim data
        incf    t5_count,f      ;Count + 1
        incf    t5_proc,f       ;Set process to 5

;******************** Dim process ***********************
;*** Dim process for TRIAC1
pp510
        movlw   d'5'            ;Set check data
        subwf   t1_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp520           ;No. Jump to TRIAC2
        decfsz  t1_count,f      ;Count out ?
        goto    pp520           ;No. Jump to TRIAC2

;End of Dim process for TRIAC1
        clrf    t1_index        ;Clear Index
        movfw   t1_r            ;Read Rising up data
        movwf   t1_count        ;Save Rising up data
        incf    t1_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t1_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp511           ;Data >= 20

; Data < 20
        clrf    t1_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t1_subindex     ;Save 20 as f
        movfw   t1_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp512           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp512           ;Jump to calculation

; Data >= 20
pp511
        movlw   d'1'            ;Set Flag data
        movwf   t1_flag         ;Set Flag = 1
        movfw   t1_r            ;Read Rising up data
        movwf   t1_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp512
        subwf   t1_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp513           ;Negative
        incf    t1_index,f      ;Positive, Index + 1
        goto    pp512           ;Again
pp513
        movfw   t1_index        ;Read index
        movwf   t1_subindex     ;Set subindex
        movlw   d'2'            ;Set process data
        movwf   t1_proc         ;Set process to 2

;*** Dim process for TRIAC2
pp520
        movlw   d'5'            ;Set check data
        subwf   t2_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp530           ;No. Jump to TRIAC3
        decfsz  t2_count,f      ;Count out ?
        goto    pp530           ;No. Jump to TRIAC3

;End of Dim process for TRIAC2
        clrf    t2_index        ;Clear Index
        movfw   t2_r            ;Read Rising up data
        movwf   t2_count        ;Save Rising up data
        incf    t2_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t2_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp521           ;Data >= 20

; Data < 20
        clrf    t2_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t2_subindex     ;Save 20 as f
        movfw   t2_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp522           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp522           ;Jump to calculation

; Data >= 20
pp521
        movlw   d'1'            ;Set Flag data
        movwf   t2_flag         ;Set Flag = 1
        movfw   t2_r            ;Read Rising up data
        movwf   t2_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp522
        subwf   t2_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp523           ;Negative
        incf    t2_index,f      ;Positive, Index + 1
        goto    pp522           ;Again
pp523
        movfw   t2_index        ;Read index
        movwf   t2_subindex     ;Set subindex
        movlw   d'2'            ;Set process data
        movwf   t2_proc         ;Set process to 2

;*** Dim process for TRIAC3
pp530
        movlw   d'5'            ;Set check data
        subwf   t3_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp540           ;No. Jump to TRIAC4
        decfsz  t3_count,f      ;Count out ?
        goto    pp540           ;No. Jump to TRIAC4

;End of Dim process for TRIAC3
        clrf    t3_index        ;Clear Index
        movfw   t3_r            ;Read Rising up data
        movwf   t3_count        ;Save Rising up data
        incf    t3_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t3_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp531           ;Data >= 20

; Data < 20
        clrf    t3_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t3_subindex     ;Save 20 as f
        movfw   t3_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp532           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp532           ;Jump to calculation

; Data >= 20
pp531
        movlw   d'1'            ;Set Flag data
        movwf   t3_flag         ;Set Flag = 1
        movfw   t3_r            ;Read Rising up data
        movwf   t3_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp532
        subwf   t3_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp533           ;Negative
        incf    t3_index,f      ;Positive, Index + 1
        goto    pp532           ;Again
pp533
        movfw   t3_index        ;Read index
        movwf   t3_subindex     ;Set subindex
        movlw   d'2'            ;Set process data
        movwf   t3_proc         ;Set process to 2

;*** Dim process for TRIAC4
pp540
        movlw   d'5'            ;Set check data
        subwf   t4_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp550           ;No. Jump to TRIAC5
        decfsz  t4_count,f      ;Count out ?
        goto    pp550           ;No. Jump to TRIAC5

;End of Dim process for TRIAC4
        clrf    t4_index        ;Clear Index
        movfw   t4_r            ;Read Rising up data
        movwf   t4_count        ;Save Rising up data
        incf    t4_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t4_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp541           ;Data >= 20

; Data < 20
        clrf    t4_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t4_subindex     ;Save 20 as f
        movfw   t4_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp542           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp542           ;Jump to calculation

; Data >= 20
pp541
        movlw   d'1'            ;Set Flag data
        movwf   t4_flag         ;Set Flag = 1
        movfw   t4_r            ;Read Rising up data
        movwf   t4_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp542
        subwf   t4_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp543           ;Negative
        incf    t4_index,f      ;Positive, Index + 1
        goto    pp542           ;Again
pp543
        movfw   t4_index        ;Read index
        movwf   t4_subindex     ;Set subindex
        movlw   d'2'            ;Set process data
        movwf   t4_proc         ;Set process to 2

;*** Dim process for TRIAC5
pp550
        movlw   d'5'            ;Set check data
        subwf   t5_proc,w       ;Check data
        btfss   status,z        ;Bright process ?
        goto    pp_end          ;No. Jump to End process
        decfsz  t5_count,f      ;Count out ?
        goto    pp_end          ;No. Jump to End process

;End of Dim process for TRIAC5
        clrf    t5_index        ;Clear Index
        movfw   t5_r            ;Read Rising up data
        movwf   t5_count        ;Save Rising up data
        incf    t5_count,f      ;Count + 1
        movlw   d'20'           ;Set check data
        subwf   t5_r,w          ;Check data
        btfsc   status,c        ;Rising up data < 20
        goto    pp551           ;Data >= 20

; Data < 20
        clrf    t5_flag         ;Set Flag = 0
        movlw   d'20'           ;Set data
        movwf   t5_subindex     ;Save 20 as f
        movfw   t5_r            ;Set Rising up data as w
        btfss   status,z        ;Rising up data = 0 ?
        goto    pp552           ;Jump to calculation
        movlw   d'1'            ;Set 1 as w
        goto    pp552           ;Jump to calculation

; Data >= 20
pp551
        movlw   d'1'            ;Set Flag data
        movwf   t5_flag         ;Set Flag = 1
        movfw   t5_r            ;Read Rising up data
        movwf   t5_subindex     ;Save Rising up data as f
        movlw   d'20'           ;Set 20 as w
pp552
        subwf   t5_subindex,f   ;f-w to f
        btfss   status,c        ;Result is negative ?
        goto    pp553           ;Negative
        incf    t5_index,f      ;Positive, Index + 1
        goto    pp552           ;Again
pp553
        movfw   t5_index        ;Read index
        movwf   t5_subindex     ;Set subindex
        movlw   d'2'            ;Set process data
        movwf   t5_proc         ;Set process to 2

pp_end
        goto    int_end         ;End of TMR1 interruption

;********************************************************
;          END of Decorative light Controller
;********************************************************

        end
